@@ -45,7 +45,7 @@ KBiff::KBiff(DCOPClient *client_, TQWidget *parent_)
     setAlignment(AlignLeft | AlignTop);
 
     // enable the session management stuff
-    connect(kapp, SIGNAL(saveYourself()), this, SLOT(saveYourself()));
+    connect(kapp, TQ_SIGNAL(saveYourself()), this, TQ_SLOT(saveYourself()));
 
     // nuke the list stuff when removed
     monitorList.setAutoDelete(true);
@@ -124,7 +124,7 @@ void KBiff::processSetup(const KBiffSetup* setup_, bool run_)
     // handle session management disabling
     if (sessions == false)
     {
-      disconnect(this, SLOT(saveYourself()));
+      disconnect(this, TQ_SLOT(saveYourself()));
       kapp->disableSessionManagement();
     }
 
@@ -152,9 +152,9 @@ void KBiff::processSetup(const KBiffSetup* setup_, bool run_)
     delete setup_;
 }
 
-void KBiff::setMailboxList(const TQList<KBiffMailbox>& mailbox_list, unsigned int poll)
+void KBiff::setMailboxList(const TQPtrList<KBiffMailbox>& mailbox_list, unsigned int poll)
 {
-    TQList<KBiffMailbox> tmp_list = mailbox_list;
+    TQPtrList<KBiffMailbox> tmp_list = mailbox_list;
 
     myMUTEX = true;
     if (isRunning())
@@ -169,23 +169,23 @@ void KBiff::setMailboxList(const TQList<KBiffMailbox>& mailbox_list, unsigned in
         monitor->setMailbox(*url);
         monitor->setPollInterval(poll);
         monitor->setMailboxKey(mbox->key);
-        connect(monitor, SIGNAL(signal_newMail(const int, const TQString&)),
-                this, SLOT(haveNewMail(const int, const TQString&)));
-        connect(monitor, SIGNAL(signal_currentStatus(const int, const TQString&, const KBiffMailState)),
-                this, SLOT(currentStatus(const int, const TQString&, const KBiffMailState)));
-        connect(monitor, SIGNAL(signal_noMail()), this, SLOT(displayPixmap()));
-        connect(monitor, SIGNAL(signal_noMail()),
-                this, SLOT(haveNoNewMail()));
-        connect(monitor, SIGNAL(signal_oldMail()), this, SLOT(displayPixmap()));
-        connect(monitor, SIGNAL(signal_oldMail()),
-                this, SLOT(haveNoNewMail()));
-        connect(monitor, SIGNAL(signal_noConn()), this, SLOT(displayPixmap()));
-        connect(monitor, SIGNAL(signal_noConn()),
-                this, SLOT(haveNoNewMail()));
-        connect(monitor, SIGNAL(signal_invalidLogin(const TQString&)),
-                this, SLOT(invalidLogin(const TQString&)));
-        connect(monitor, SIGNAL(signal_fetchMail(const TQString&)),
-                this, SLOT(slotLaunchFetchClient(const TQString&)));
+        connect(monitor, TQ_SIGNAL(signal_newMail(const int, const TQString&)),
+                this, TQ_SLOT(haveNewMail(const int, const TQString&)));
+        connect(monitor, TQ_SIGNAL(signal_currentStatus(const int, const TQString&, const KBiffMailState)),
+                this, TQ_SLOT(currentStatus(const int, const TQString&, const KBiffMailState)));
+        connect(monitor, TQ_SIGNAL(signal_noMail()), this, TQ_SLOT(displayPixmap()));
+        connect(monitor, TQ_SIGNAL(signal_noMail()),
+                this, TQ_SLOT(haveNoNewMail()));
+        connect(monitor, TQ_SIGNAL(signal_oldMail()), this, TQ_SLOT(displayPixmap()));
+        connect(monitor, TQ_SIGNAL(signal_oldMail()),
+                this, TQ_SLOT(haveNoNewMail()));
+        connect(monitor, TQ_SIGNAL(signal_noConn()), this, TQ_SLOT(displayPixmap()));
+        connect(monitor, TQ_SIGNAL(signal_noConn()),
+                this, TQ_SLOT(haveNoNewMail()));
+        connect(monitor, TQ_SIGNAL(signal_invalidLogin(const TQString&)),
+                this, TQ_SLOT(invalidLogin(const TQString&)));
+        connect(monitor, TQ_SIGNAL(signal_fetchMail(const TQString&)),
+                this, TQ_SLOT(slotLaunchFetchClient(const TQString&)));
         monitorList.append(monitor);
     }
     myMUTEX = false;
@@ -257,7 +257,7 @@ void KBiff::enterEvent(TQEvent *e)
 
     // popup the status in one second
     statusTimer = new TQTimer(this);
-    connect(statusTimer, SIGNAL(timeout()), this, SLOT(popupStatus()));
+    connect(statusTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(popupStatus()));
 
     statusTimer->start(1000, true);
 }
@@ -536,8 +536,8 @@ void KBiff::haveNewMail(const int num, const TQString& the_mailbox)
     if (notify)
     {
         KBiffNotify *notify_dlg = new KBiffNotify(this, num, the_mailbox);
-        connect(notify_dlg, SIGNAL(signalLaunchMailClient()),
-                this, SLOT(slotLaunchMailClient()));
+        connect(notify_dlg, TQ_SIGNAL(signalLaunchMailClient()),
+                this, TQ_SLOT(slotLaunchMailClient()));
         notifyList.append(notify_dlg);
         notify_dlg->show();
 
@@ -643,7 +643,7 @@ void KBiff::dock()
 
     // (un)dock it!
     this->show();
-    TQTimer::singleShot(1000, this, SLOT(displayPixmap()));
+    TQTimer::singleShot(1000, this, TQ_SLOT(displayPixmap()));
 }
 
 void KBiff::setup()
@@ -727,35 +727,35 @@ void KBiff::popupMenu()
     if (isSecure == false)
     {
         if (docked)
-            popup->insertItem(i18n("&UnDock"), this, SLOT(dock()));
+            popup->insertItem(i18n("&UnDock"), this, TQ_SLOT(dock()));
         else
-            popup->insertItem(i18n("&Dock"), this, SLOT(dock()));
-        popup->insertItem(i18n("&Setup..."), this, SLOT(setup()));
+            popup->insertItem(i18n("&Dock"), this, TQ_SLOT(dock()));
+        popup->insertItem(i18n("&Setup..."), this, TQ_SLOT(setup()));
         popup->insertSeparator();
-        popup->insertItem(i18n("&Help..."), this, SLOT(invokeHelp()));
+        popup->insertItem(i18n("&Help..."), this, TQ_SLOT(invokeHelp()));
         popup->insertSeparator();
 
         int check_id;
-        check_id = popup->insertItem(i18n("&Check Mail Now"), this, SLOT(checkMailNow()));
+        check_id = popup->insertItem(i18n("&Check Mail Now"), this, TQ_SLOT(checkMailNow()));
         int read_id;
-        read_id = popup->insertItem(i18n("&Read Mail Now"), this, SLOT(readMailNow()));
+        read_id = popup->insertItem(i18n("&Read Mail Now"), this, TQ_SLOT(readMailNow()));
 
         if (isRunning())
         {
             popup->setItemEnabled(check_id, true);
             popup->setItemEnabled(read_id, true);
-            popup->insertItem(i18n("&Stop"), this, SLOT(stop()));
+            popup->insertItem(i18n("&Stop"), this, TQ_SLOT(stop()));
         }
         else
         {
             popup->setItemEnabled(check_id, false);
             popup->setItemEnabled(read_id, false);
-            popup->insertItem(i18n("&Start"), this, SLOT(start()));
+            popup->insertItem(i18n("&Start"), this, TQ_SLOT(start()));
         }
         popup->insertSeparator();
     }
 
-    popup->insertItem(i18n("E&xit"), kapp, SLOT(quit()));
+    popup->insertItem(i18n("E&xit"), kapp, TQ_SLOT(quit()));
 
     popup->popup(TQCursor::pos());
 }
