@@ -256,7 +256,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
 
         imap = new KBiffImap;
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkImap()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkImap()));
         server   = url.host();
         user     = url.user();
         password = url.pass();
@@ -281,7 +281,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
 
         imap = new KBiffImap;
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkImap()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkImap()));
         server   = url.host();
         user     = url.user();
         password = url.pass();
@@ -304,7 +304,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
 
         pop = new KBiffPop;
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkPop()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkPop()));
         server   = url.host();
         user     = url.user();
         password = url.pass();
@@ -332,7 +332,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
 
         pop = new KBiffPop;
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkPop()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkPop()));
         server   = url.host();
         user     = url.user();
         password = url.pass();
@@ -356,7 +356,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
     {
         disconnect(this);
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkMbox()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkMbox()));
         mailbox = url.path();
 
         simpleURL = "mbox:" + mailbox;
@@ -366,7 +366,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
     {
         disconnect(this);
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkLocal()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkLocal()));
         mailbox = url.path();
 
         simpleURL = "file:" + mailbox;
@@ -376,7 +376,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
     {
         disconnect(this);
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkMaildir()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkMaildir()));
         mailbox = url.path();
 
         simpleURL = "maildir:" + mailbox;
@@ -386,7 +386,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
     {
         disconnect(this);
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkMHdir()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkMHdir()));
         mailbox = url.path();
 
         simpleURL = "mh:" + mailbox;
@@ -398,7 +398,7 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
 
         nntp = new KBiffNntp;
 
-        connect(this, SIGNAL(signal_checkMail()), SLOT(checkNntp()));
+        connect(this, TQ_SIGNAL(signal_checkMail()), TQ_SLOT(checkNntp()));
         server   = url.host();
         user     = url.user();
         password = url.pass();
