@@ -252,10 +252,10 @@ typedef enum
  *    mon.setPollInterval(15);
  *    mon.start();
  *
- *    connect(&mon, SIGNAL(signal_newMail()), this, SLOT(processNewMail()));
- *    connect(&mon, SIGNAL(signal_oldMail()), this, SLOT(processOldMail()));
- *    connect(&mon, SIGNAL(signal_noMail()), this, SLOT(processNoMail()));
- *    connect(&mon, SIGNAL(signal_noConn()), this, SLOT(processNoConn()));
+ *    connect(&mon, TQ_SIGNAL(signal_newMail()), this, TQ_SLOT(processNewMail()));
+ *    connect(&mon, TQ_SIGNAL(signal_oldMail()), this, TQ_SLOT(processOldMail()));
+ *    connect(&mon, TQ_SIGNAL(signal_noMail()), this, TQ_SLOT(processNoMail()));
+ *    connect(&mon, TQ_SIGNAL(signal_noConn()), this, TQ_SLOT(processNoConn()));
  * </PRE>
  *
  * @short A "biff" class that monitors local and remote mailboxes
@@ -265,7 +265,7 @@ typedef enum
 class KBiffMonitor : public TQObject
 {
 
-    Q_OBJECT
+    TQ_OBJECT
 public:
 
     /**
