@@ -98,21 +98,21 @@ KBiffSetup::KBiffSetup(const TQString& profile_, bool secure_)
                                                     profile_groupbox);
   whatsthis = i18n("Create a new profile");
   TQWhatsThis::add(new_profile_button, whatsthis);
-  connect(new_profile_button, SIGNAL(clicked()), SLOT(slotAddNewProfile()));
+  connect(new_profile_button, TQ_SIGNAL(clicked()), TQ_SLOT(slotAddNewProfile()));
 
   // Rename Profile button
   TQPushButton *rename_profile_button = new TQPushButton(i18n("&Rename..."),
                                                        profile_groupbox);
   whatsthis = i18n("Rename the current profile");
   TQWhatsThis::add(rename_profile_button, whatsthis);
-  connect(rename_profile_button, SIGNAL(clicked()), SLOT(slotRenameProfile()));
+  connect(rename_profile_button, TQ_SIGNAL(clicked()), TQ_SLOT(slotRenameProfile()));
 
   // Delete Profile button
   TQPushButton *delete_profile_button = new TQPushButton(i18n("&Delete"),
                                                        profile_groupbox);
   whatsthis = i18n("Delete the current profile");
   TQWhatsThis::add(delete_profile_button, whatsthis);
-  connect(delete_profile_button, SIGNAL(clicked()), SLOT(slotDeleteProfile()));
+  connect(delete_profile_button, TQ_SIGNAL(clicked()), TQ_SLOT(slotDeleteProfile()));
 
   // setup the tabs
   TQTabWidget *tabctl = new TQTabWidget(this);
@@ -121,12 +121,12 @@ KBiffSetup::KBiffSetup(const TQString& profile_, bool secure_)
   mailboxTab = new KBiffMailboxTab(the_profile, tabctl);
   aboutTab   = new KBiffAboutTab(tabctl); 
 
-  connect(comboProfile, SIGNAL(highlighted(const TQString&)),
-          generalTab, SLOT(readConfig(const TQString&)));
-  connect(comboProfile, SIGNAL(highlighted(const TQString&)),
-          newmailTab, SLOT(readConfig(const TQString&)));
-  connect(comboProfile, SIGNAL(highlighted(const TQString&)),
-          mailboxTab, SLOT(readConfig(const TQString&)));
+  connect(comboProfile, TQ_SIGNAL(highlighted(const TQString&)),
+          generalTab, TQ_SLOT(readConfig(const TQString&)));
+  connect(comboProfile, TQ_SIGNAL(highlighted(const TQString&)),
+          newmailTab, TQ_SLOT(readConfig(const TQString&)));
+  connect(comboProfile, TQ_SIGNAL(highlighted(const TQString&)),
+          mailboxTab, TQ_SLOT(readConfig(const TQString&)));
 
   // add the tabs
   tabctl->addTab(generalTab, i18n("General"));
@@ -136,16 +136,16 @@ KBiffSetup::KBiffSetup(const TQString& profile_, bool secure_)
 
   // help button
   TQPushButton *help_button = new TQPushButton(i18n("&Help"), this);
-  connect(help_button, SIGNAL(clicked()), SLOT(invokeHelp()));
+  connect(help_button, TQ_SIGNAL(clicked()), TQ_SLOT(invokeHelp()));
 
   // ok button
   TQPushButton *ok_button = new TQPushButton(i18n("&OK"), this);
   ok_button->setDefault(true);
-  connect(ok_button, SIGNAL(clicked()), SLOT(slotDone()));
+  connect(ok_button, TQ_SIGNAL(clicked()), TQ_SLOT(slotDone()));
 
   // cancel button
   TQPushButton *cancel_button = new TQPushButton(i18n("&Cancel"), this);
-  connect(cancel_button, SIGNAL(clicked()), SLOT(reject()));
+  connect(cancel_button, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
   // are we secure?
   isSecure = secure_;
@@ -826,13 +826,13 @@ KBiffNewMailTab::KBiffNewMailTab(const TQString& profile_, TQWidget *parent_)
   checkStatus = new TQCheckBox(i18n("&Floating Status"), this);
 
   // connect some slots and signals
-  connect(buttonBrowsePlaySound, SIGNAL(clicked()), SLOT(browsePlaySound()));
-  connect(buttonBrowseRunCommand, SIGNAL(clicked()), SLOT(browseRunCommand()));
-  connect(buttonBrowseRunResetCommand, SIGNAL(clicked()), SLOT(browseRunResetCommand()));
-  connect(checkPlaySound, SIGNAL(toggled(bool)), SLOT(enablePlaySound(bool)));
-  connect(buttonTestPlaySound, SIGNAL(clicked()), SLOT(testPlaySound()));
-  connect(checkRunCommand, SIGNAL(toggled(bool)), SLOT(enableRunCommand(bool)));
-  connect(checkRunResetCommand, SIGNAL(toggled(bool)), SLOT(enableRunResetCommand(bool)));
+  connect(buttonBrowsePlaySound, TQ_SIGNAL(clicked()), TQ_SLOT(browsePlaySound()));
+  connect(buttonBrowseRunCommand, TQ_SIGNAL(clicked()), TQ_SLOT(browseRunCommand()));
+  connect(buttonBrowseRunResetCommand, TQ_SIGNAL(clicked()), TQ_SLOT(browseRunResetCommand()));
+  connect(checkPlaySound, TQ_SIGNAL(toggled(bool)), TQ_SLOT(enablePlaySound(bool)));
+  connect(buttonTestPlaySound, TQ_SIGNAL(clicked()), TQ_SLOT(testPlaySound()));
+  connect(checkRunCommand, TQ_SIGNAL(toggled(bool)), TQ_SLOT(enableRunCommand(bool)));
+  connect(checkRunResetCommand, TQ_SIGNAL(toggled(bool)), TQ_SLOT(enableRunResetCommand(bool)));
 
   // NOW DO THE LAYOUT
   TQHBoxLayout *run_command_layout = new TQHBoxLayout(5);
@@ -1106,16 +1106,16 @@ KBiffMailboxAdvanced::KBiffMailboxAdvanced()
   TQPushButton *cancel = new TQPushButton(i18n("&Cancel"), this);
 
   // connect all the slots to signals
-  connect(preauth, SIGNAL(toggled(bool)), SLOT(preauthModified(bool)));
-  connect(keepalive, SIGNAL(toggled(bool)), SLOT(keepaliveModified(bool)));
-  connect(async, SIGNAL(toggled(bool)), SLOT(asyncModified(bool)));
-  connect(apop, SIGNAL(toggled(bool)), SLOT(apopModified(bool)));
-  connect(port, SIGNAL(textChanged(const TQString&)),
-                SLOT(portModified(const TQString&)));
-  connect(ok, SIGNAL(clicked()), SLOT(accept()));
-  connect(cancel, SIGNAL(clicked()), SLOT(reject()));
-  connect(timeout, SIGNAL(textChanged(const TQString&)),
-                   SLOT(timeoutModified(const TQString&)));
+  connect(preauth, TQ_SIGNAL(toggled(bool)), TQ_SLOT(preauthModified(bool)));
+  connect(keepalive, TQ_SIGNAL(toggled(bool)), TQ_SLOT(keepaliveModified(bool)));
+  connect(async, TQ_SIGNAL(toggled(bool)), TQ_SLOT(asyncModified(bool)));
+  connect(apop, TQ_SIGNAL(toggled(bool)), TQ_SLOT(apopModified(bool)));
+  connect(port, TQ_SIGNAL(textChanged(const TQString&)),
+                TQ_SLOT(portModified(const TQString&)));
+  connect(ok, TQ_SIGNAL(clicked()), TQ_SLOT(accept()));
+  connect(cancel, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
+  connect(timeout, TQ_SIGNAL(textChanged(const TQString&)),
+                   TQ_SLOT(timeoutModified(const TQString&)));
 
   // NOW DO THE LAYOUT
   TQGridLayout *top_layout = new TQGridLayout(this, 7, 4, 12);
@@ -1331,16 +1331,16 @@ KBiffMailboxTab::KBiffMailboxTab(const TQString& profile_, TQWidget *parent_)
   enableFetchCommand(false);
 
   // connect all the signals
-  connect(mailboxes, SIGNAL(selectionChanged(TQListViewItem *)),
-                     SLOT(slotMailboxSelected(TQListViewItem *)));
-  connect(new_mailbox, SIGNAL(clicked()), SLOT(slotNewMailbox()));
-  connect(delete_mailbox, SIGNAL(clicked()), SLOT(slotDeleteMailbox()));
-  connect(comboProtocol, SIGNAL(highlighted(int)),
-                         SLOT(protocolSelected(int)));
-  connect(buttonBrowse, SIGNAL(clicked()), SLOT(browse()));
-  connect(advanced_button, SIGNAL(clicked()), SLOT(advanced()));
-  connect(buttonBrowseFetchCommand, SIGNAL(clicked()), SLOT(browseFetchCommand()));
-  connect(checkFetchCommand, SIGNAL(toggled(bool)), SLOT(enableFetchCommand(bool)));
+  connect(mailboxes, TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+                     TQ_SLOT(slotMailboxSelected(TQListViewItem *)));
+  connect(new_mailbox, TQ_SIGNAL(clicked()), TQ_SLOT(slotNewMailbox()));
+  connect(delete_mailbox, TQ_SIGNAL(clicked()), TQ_SLOT(slotDeleteMailbox()));
+  connect(comboProtocol, TQ_SIGNAL(highlighted(int)),
+                         TQ_SLOT(protocolSelected(int)));
+  connect(buttonBrowse, TQ_SIGNAL(clicked()), TQ_SLOT(browse()));
+  connect(advanced_button, TQ_SIGNAL(clicked()), TQ_SLOT(advanced()));
+  connect(buttonBrowseFetchCommand, TQ_SIGNAL(clicked()), TQ_SLOT(browseFetchCommand()));
+  connect(checkFetchCommand, TQ_SIGNAL(toggled(bool)), TQ_SLOT(enableFetchCommand(bool)));
 
   // NOW DO THE LAYOUT
   TQHBoxLayout *fetch_command_layout = new TQHBoxLayout(5);
@@ -1943,8 +1943,8 @@ KBiffAboutTab::KBiffAboutTab(TQWidget *parent_)
   logo_label->setUnderline(false);
   logo_label->setGlow(false);
   logo_label->setFloat(true);
-  connect(logo_label, SIGNAL(leftClickedURL(const TQString&)),
-                      SLOT(homepage(const TQString&)));
+  connect(logo_label, TQ_SIGNAL(leftClickedURL(const TQString&)),
+                      TQ_SLOT(homepage(const TQString&)));
 
   TQLabel *version_label = new TQLabel(this);
   version_label->setText(TQString("Version %1\n\nCopyright (C) 1998-2008\nKurt Granroth").arg(kbiff_version));
@@ -1955,8 +1955,8 @@ KBiffAboutTab::KBiffAboutTab(TQWidget *parent_)
   email_label->setUnderline(false);
   email_label->setGlow(false);
   email_label->setFloat(true);
-  connect(email_label, SIGNAL(leftClickedURL(const TQString&)),
-                       SLOT(mailTo(const TQString&)));
+  connect(email_label, TQ_SIGNAL(leftClickedURL(const TQString&)),
+                       TQ_SLOT(mailTo(const TQString&)));
 
   // about tab text layout
   TQVBoxLayout *text_layout = new TQVBoxLayout(0);
@@ -2003,8 +2003,8 @@ KBiffNewDlg::KBiffNewDlg(TQWidget* parent_, const char * name_)
   // cancel button
   TQPushButton* button_cancel = new TQPushButton(i18n("&Cancel"), this);
 
-  connect(button_ok, SIGNAL(clicked()), SLOT(accept()));
-  connect(button_cancel, SIGNAL(clicked()), SLOT(reject()));
+  connect(button_ok, TQ_SIGNAL(clicked()), TQ_SLOT(accept()));
+  connect(button_cancel, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
   // NOW DO THE LAYOUT
   TQGridLayout *top_layout = new TQGridLayout(this, 2, 3, 12);
